@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/php_classes/PrintIPP.php,v 1.1 2008/06/21 00:30:57 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/php_classes/PrintIPP.php,v 1.3 2010/09/06 22:41:41 harding Exp $
  *
  * Class PrintIPP - Send IPP requests, Get and parses IPP Responses.
  *
@@ -481,7 +481,7 @@ class PrintIPP extends BasicIPP {
                          . $this->meta->which_jobs 
                          . $this->meta->my_jobs
                          ;
-       if ($subset)
+       if ($subset) {
            $this->stringjob .=
                           chr(0x44) // keyword
                          . self::_giveMeStringLength('requested-attributes')
@@ -504,6 +504,16 @@ class PrintIPP extends BasicIPP {
                          . self::_giveMeStringLength('job-state-reason')
                          . 'job-state-reason'
                          ;
+        }
+        else { # cups 1.4.4 doesn't return much of anything without this
+            $this->stringjob .=
+                          chr(0x44) // keyword
+                         . self::_giveMeStringLength('requested-attributes')
+                         . 'requested-attributes'
+                         . self::_giveMeStringLength('all')
+                         . 'all'
+                         ;
+        }
         $this->stringjob .= chr(0x03); // end-of-attributes | end-of-attributes-tag
                          
         self::_putDebug(sprintf(_("String sent to the server is:\n%s\n"), $this->stringjob));
@@ -853,7 +863,11 @@ class PrintIPP extends BasicIPP {
                     $this->jobs_attributes->$job_index->$php_name->_type = $type;
                     $this->jobs_attributes->$job_index->$php_name->_range = $range;
                     for ($j = 0 ; $j < (count($this->parsed[$job_nbr][$i]) - 3) ; $j ++) {
-                        $value = self::_interpretAttribute($name,$type,$this->parsed[$job_nbr][$i][$j]);
+                        # This causes incorrect parsing of integer job attributes.
+                        # 2010-08-16
+                        # bpkroth
+                        #$value = self::_interpretAttribute($name,$type,$this->parsed[$job_nbr][$i][$j]);
+                        $value = $this->parsed[$job_nbr][$i][$j];
                         $index = '_value'.$j;
                         $this->jobs_attributes->$job_index->$php_name->$index = $value;
                         }
