@@ -44,10 +44,10 @@ $host = "localhost"; // set serve'rs host here
 $ssl = false; // enable ssl if true
 $printer_uri = "/printers/Parallel_Port_1"; // set printer uri here
 $language = "fr_fr";
-$user = "test"; // valid user from lpadmin group
-$password = "0123Test"; // his password
+$user = "admin"; // valid user from lpadmin group
+$password = "password"; // his password
 $document_uri = "http://localhost/";
-$debug_level = 3; // 1: silent; 3: very verbose
+$debug_level = 5; // 5: silent; 0: very verbose
 
 
 error_reporting(E_ALL|E_STRICT);
@@ -59,7 +59,7 @@ error_reporting(E_ALL|E_STRICT);
 
 
 function __autoload($class_name) {
-   require_once ../$class_name . '.php';
+   require_once "printipp/$class_name.php";
 }
    
 
@@ -81,7 +81,8 @@ function __autoload($class_name) {
 
 <?php
 
-//$ipp = new PrintIPP(); // Basic PrintIPP
+//$ipp = new BasicIPP(); // only printJob operation
+//$ipp = new PrintIPP(); // RFC 2911 mandatory operations
 //$ipp = new ExtendedPrintIPP(); // extended IPP
 $ipp = new CupsPrintIPP(); // extended IPP with CUPS specific stuff
 
