@@ -1,6 +1,6 @@
 <?php
 /*
- *Example of use of PrintIPP
+ *Example of use of BasicIPP, with Exceptions handling
  *
  * Copyright(C) 2008 Thomas Harding
  * All rights reserved.
@@ -42,14 +42,18 @@ error_reporting(E_ALL|E_STRICT);
 * SETTINGS, YOU ARE PLEASED TO PLAY WITH THEM
 *
 */
-require_once('../CupsPrintIPP.php'); 
+require_once('printipp/BasicIPP.php'); 
+
+echo memory_get_usage  (false),"\n";
+echo memory_get_usage  (true),"\n";
+
 $debug = 3; // 0 to 4 (less verbose)
 $host="localhost";
-$printer="/printers/Parallel_Port_2";
-$port=8631;
+$printer="/printers/Parallel_Port_1";
+$port=631;
 $logfile="/tmp/phpprintipp";
 $username="www-data";
-$password=false; // set it if you need authentication to print or cancel
+$password=false; // set it if you need authentication to print
 $handle_http_exceptions=false;
 $handle_ipp_exceptions=false;
 $mediatype="text/plain";
@@ -59,7 +63,7 @@ END OF SETTINGS
 
 
 //
-$ipp = new CupsPrintIPP(); 
+$ipp = new BasicIPP(); 
 $ipp->with_exceptions = $handle_ipp_exceptions;
 $ipp->handle_http_exceptions = $handle_http_exceptions;
 $ipp->setHost($host);
@@ -100,7 +104,6 @@ try
   try
   {
     printf(_("Job status: %s\n"), $ipp->printJob()); // Print job, display job status 
-    printf(_("Cancel job: %s"), $ipp->CancelJob($ipp->last_job)); // comment to deforrest ;)
   }
   catch (httpException $e)
   {
@@ -121,5 +124,11 @@ if ($debug)
   print $ipp->getDebug(); // display debugging output
 ?>
 
-END "PRINT THEN CANCEL" TEST
+<?php
+echo memory_get_usage  (false),"\n";
+echo memory_get_usage  (true),"\n";
+
+?>
+
+END "EXCEPTIONS" TEST
 <?php exit (0) ?>
